kniteditor
==========

.. image:: https://travis-ci.org/AllYarnsAreBeautiful/kniteditor.svg
   :target: https://travis-ci.org/AllYarnsAreBeautiful/kniteditor
   :alt: Build Status

.. image:: https://codeclimate.com/github/AllYarnsAreBeautiful/kniteditor/badges/gpa.svg
   :target: https://codeclimate.com/github/AllYarnsAreBeautiful/kniteditor
   :alt: Code Climate

.. image:: https://codeclimate.com/github/AllYarnsAreBeautiful/kniteditor/badges/coverage.svg
   :target: https://codeclimate.com/github/AllYarnsAreBeautiful/kniteditor/coverage
   :alt: Test Coverage

.. image:: https://codeclimate.com/github/AllYarnsAreBeautiful/kniteditor/badges/issue_count.svg
   :target: https://codeclimate.com/github/AllYarnsAreBeautiful/kniteditor
   :alt: Issue Count

.. image:: https://badge.fury.io/py/kniteditor.svg
   :target: https://pypi.python.org/pypi/kniteditor
   :alt: Issue Count
   
.. image:: https://img.shields.io/pypi/dm/kniteditor.svg
   :target: https://pypi.python.org/pypi/kniteditor#downloads
   :alt: Downloads from pypi   

.. image:: https://readthedocs.org/projects/kniteditor/badge/?version=latest
   :target: https://kniteditor.readthedocs.org
   :alt: Read the Documentation

.. image:: https://landscape.io/github/AllYarnsAreBeautiful/kniteditor/master/landscape.svg?style=flat
   :target: https://landscape.io/github/AllYarnsAreBeautiful/kniteditor/master
   :alt: Code Health

.. image:: https://badge.waffle.io/AllYarnsAreBeautiful/ayab-desktop.svg?label=ready&title=issues%20ready
   :target: https://waffle.io/AllYarnsAreBeautiful/ayab-desktop
   :alt: Issues ready to work on

For installation instructions and more, `see the documentation
<http://kniteditor.readthedocs.io/>`__.
